@@ -123,9 +123,12 @@ public:
         newVolume = qBound<qint64>(0, newVolume, PA_VOLUME_MAX);
         pa_cvolume newCVolume = cVolume;
         if (channel == -1) { // -1 all channels
-            const qint64 diff = newVolume - pa_cvolume_max(&cVolume);
+            const qint64 orig = pa_cvolume_max(&cVolume);
+            const qint64 diff = newVolume - orig;
             for (int i = 0; i < newCVolume.channels; ++i) {
-                newCVolume.values[i] = qBound<qint64>(0, newCVolume.values[i] + diff, PA_VOLUME_MAX);
+                const qint64 channel = newCVolume.values[i];
+                const qint64 channelDiff = orig == 0 ? diff : diff * channel / orig;
+                newCVolume.values[i] = qBound<qint64>(0, newCVolume.values[i] + channelDiff, PA_VOLUME_MAX);
             }
         } else {
             Q_ASSERT(newCVolume.channels > channel);
