@@ -21,14 +21,13 @@ void finish_callback(ca_context *c, unsigned int id, int error_code, void *userd
 {
     Q_UNUSED(c)
     Q_UNUSED(id)
-    Q_UNUSED(error_code)
 
     if (userdata == nullptr) {
         return;
     }
 
-    CallbackData *cb_data = static_cast<CallbackData *>(userdata);
-    cb_data->object->playingFinished(cb_data->name);
+    auto *cb_data = static_cast<CallbackData *>(userdata);
+    cb_data->object->playingFinished(cb_data->name, error_code);
 
     delete (cb_data);
 };
@@ -76,14 +75,21 @@ void SpeakerTest::testChannel(const QString &name)
     // there is no subwoofer sound in the freedesktop theme https://gitlab.freedesktop.org/xdg/xdg-sound-theme/-/issues/7
     const QString sound_name = (name == QLatin1String("lfe")) ? QStringLiteral("audio-channel-rear-center") : QStringLiteral("audio-channel-%1").arg(name);
 
-    ca_proplist_sets(proplist, CA_PROP_EVENT_ID, sound_name.toLatin1().data());
-    if (ca_context_play_full(context, 0, proplist, finish_callback, cb_data) != CA_SUCCESS) {
-        // Try a different sound name.
-        ca_proplist_sets(proplist, CA_PROP_EVENT_ID, "audio-test-signal");
-        if (ca_context_play_full(context, 0, proplist, finish_callback, cb_data) != CA_SUCCESS) {
-            // Finaly try this... if this doesn't work, then stuff it.
-            ca_proplist_sets(proplist, CA_PROP_EVENT_ID, "bell-window-system");
-            ca_context_play_full(context, 0, proplist, finish_callback, cb_data);
+    int error_code = CA_SUCCESS;
+    for (const QString &soundName : {sound_name,
+                                     QStringLiteral("audio-test-signal"), // Fallback sounds
+                                     QStringLiteral("bell-window-system"),
+                                     QString()}) {
+        if (soundName.isEmpty()) {
+            // We are here because all of the fallback sounds failed to play
+            playingFinished(name, error_code);
+            break;
+        }
+
+        ca_proplist_sets(proplist, CA_PROP_EVENT_ID, soundName.toLatin1().data());
+        error_code = ca_context_play_full(context, 0, proplist, finish_callback, cb_data);
+        if (error_code == CA_SUCCESS) {
+            break;
         }
     }
 
@@ -96,8 +102,12 @@ QStringList SpeakerTest::playingChannels() const
     return m_playingChannels;
 }
 
-void SpeakerTest::playingFinished(const QString &name)
+void SpeakerTest::playingFinished(const QString &name, int errorCode)
 {
     m_playingChannels.removeOne(name);
     Q_EMIT playingChannelsChanged();
+
+    if (errorCode != CA_SUCCESS) {
+        Q_EMIT showErrorMessage(ca_strerror(errorCode));
+    };
 }
